@@ -57,6 +57,7 @@ from scipy.optimize import linear_sum_assignment
 from skimage.measure import regionprops
 from skimage.segmentation import relabel_sequential
 from sklearn.metrics import confusion_matrix
+from scipy.stats import hmean
 
 from deepcell_toolbox import erode_edges
 from deepcell_toolbox.compute_overlap import compute_overlap  # pylint: disable=E0401
@@ -178,9 +179,13 @@ class ObjectAccuracy(object):  # pylint: disable=useless-object-inheritance
                              'is: {}.  Shape of y_true is: {}'.format(
                                  y_pred.shape, y_true.shape))
 
-        # Relabel y_true and y_pred so the labels are consecutive
-        y_true, _, _ = relabel_sequential(y_true)
-        y_pred, _, _ = relabel_sequential(y_pred)
+        if not np.issubdtype(y_true.dtype, np.integer):
+            warnings.warn('Casting y_true from {} to int'.format(y_true.dtype))
+            y_true = y_true.astype('int32')
+
+        if not np.issubdtype(y_pred.dtype, np.integer):
+            warnings.warn('Casting y_pred from {} to int'.format(y_pred.dtype))
+            y_pred = y_pred.astype('int32')
 
         self.y_true = y_true
         self.y_pred = y_pred
@@ -204,6 +209,10 @@ class ObjectAccuracy(object):  # pylint: disable=useless-object-inheritance
         self.true_det_in_catastrophe = 0
         self.pred_det_in_catastrophe = 0
 
+        self.precision = 0
+        self.recall = 0
+        self.f1 = 0
+
         # Initialize lists and dicts to store indices where errors occur
         self.correct_indices = {}
         self.correct_indices['y_true'] = []
@@ -590,6 +599,11 @@ class ObjectAccuracy(object):  # pylint: disable=useless-object-inheritance
         Returns:
             pandas.DataFrame: Single row dataframe with error types as columns
         """
+
+        self.precision = self.correct_detections / self.n_pred
+        self.recall = self.correct_detections / self.n_true
+        self.f1 = hmean([self.recall, self.precision])
+
         D = {
             'n_pred': self.n_pred,
             'n_true': self.n_true,
@@ -602,7 +616,10 @@ class ObjectAccuracy(object):  # pylint: disable=useless-object-inheritance
             'pred_det_in_catastrophe': self.pred_det_in_catastrophe,
             'merge': self.merge,
             'split': self.split,
-            'catastrophe': self.catastrophe
+            'catastrophe': self.catastrophe,
+            'precision': self.precision,
+            'recall': self.recall,
+            'f1': self.f1
         }
 
         if self.seg is True:
@@ -873,9 +890,22 @@ class Metrics(object):
         self.stats = pd.DataFrame()
         self.predictions = []
 
+        # boolean so that warning only gets displayed once
+        relabel_flag = False
         for i in range(y_true.shape[0]):
-            o = ObjectAccuracy(y_true[i],
-                               y_pred[i],
+
+            # check if labels aren't sequential, raise warning on first occurence if so
+            true_batch, pred_batch = y_true[i], y_pred[i]
+            true_batch_relabel, _, _ = relabel_sequential(true_batch)
+            pred_batch_relabel, _, _ = relabel_sequential(pred_batch)
+
+            if not (np.array_equal(true_batch, true_batch_relabel) and
+                    np.array_equal(pred_batch, pred_batch_relabel)):
+
+                    # segmentations were relabeled
+                    relabel_flag = True
+            o = ObjectAccuracy(true_batch_relabel,
+                               pred_batch_relabel,
                                cutoff1=self.cutoff1,
                                cutoff2=self.cutoff2,
                                seg=self.seg,
@@ -887,6 +917,12 @@ class Metrics(object):
             if i % 500 == 0:
                 logging.info('{} samples processed'.format(i))
 
+        if relabel_flag:
+            warnings.warn(
+                'Provided data is being relabeled. Cell ids from metrics will not match '
+                'cell ids in original data. Relabel your data prior to running the '
+                'metrics package if you wish to maintain cell ids')
+
         # Write out summed statistics
         for k, v in self.stats.iteritems():
             if k == 'seg':
