@@ -159,7 +159,7 @@ def _sample2_2(w, h, imw, imh, merge=True, similar_size=False):
     im2[im2 == b] = a
 
     # ensure that output is sequential so it doesn't get subsequently relabeled
-    im2, _, _ = relabel_sequential(im2)
+    im2, _, _ = relabel_sequential(im2.astype('int'))
 
     # record which values of im1 were correctly assigned
     im1_wrong = {a, b}
@@ -372,6 +372,11 @@ class TestMetricsObject():
         with testing.assert_raises(ValueError):
             m.calc_object_stats(np.random.rand(10, 10), np.random.rand(10, 10))
 
+        # data that needs to be relabeled raises a warning
+        with pytest.warns(UserWarning):
+            y_pred[0, 0, 0] = 40
+            m.calc_object_stats(y_true, y_pred)
+
     def test_save_to_json(self, tmpdir):
         name = 'test'
         tmpdir = str(tmpdir)
@@ -779,7 +784,7 @@ class TestObjectAccuracy():
         columns = ['n_pred', 'n_true', 'correct_detections', 'missed_detections',
                    'gained_detections', 'missed_det_from_merge', 'gained_det_from_split',
                    'true_det_in_catastrophe', 'pred_det_in_catastrophe', 'merge', 'split',
-                   'catastrophe', 'jaccard']
+                   'catastrophe', 'jaccard', 'precision', 'recall', 'f1']
         assert np.array_equal(sorted(columns), sorted(list(df.columns)))
 
         # Check seg True case
@@ -789,7 +794,7 @@ class TestObjectAccuracy():
         columns = ['n_pred', 'n_true', 'correct_detections', 'missed_detections',
                    'gained_detections', 'missed_det_from_merge', 'gained_det_from_split',
                    'true_det_in_catastrophe', 'pred_det_in_catastrophe', 'merge', 'split',
-                   'catastrophe', 'seg', 'jaccard']
+                   'catastrophe', 'seg', 'jaccard', 'precision', 'recall', 'f1']
         assert np.array_equal(sorted(columns), sorted(list(df.columns)))
 
     def test_assign_plot_values(self):
